==> ncbi-blast+_2.11.0+ds.orig.tar.xz: ncbi-blast-2.11.0+-src/c++/include/connect/ncbi_localip.hpp <==
#ifndef CONNECT___NCBI_CONN_LOCALIP__HPP
#define CONNECT___NCBI_CONN_LOCALIP__HPP

/* $Id: ncbi_localip.hpp 598846 2019-12-16 14:52:32Z lavr $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
 *               National Center for Biotechnology Information
 *
 *  This software/database is a "United States Government Work" under the
 *  terms of the United States Copyright Act.  It was written as part of
 *  the author's official duties as a United States Government employee and
 *  thus cannot be copyrighted.  This software/database is freely available
 *  to the public for use. The National Library of Medicine and the U.S.
 *  Government have not placed any restriction on its use or reproduction.
 *
 *  Although all reasonable efforts have been taken to ensure the accuracy
 *  and reliability of the software and data, the NLM and the U.S.
 *  Government do not and cannot warrant the performance or results that
 *  may be obtained by using this software or data. The NLM and the U.S.
 *  Government disclaim all warranties, express or implied, including
 *  warranties of performance, merchantability or fitness for any particular
 *  purpose.
 *
 *  Please cite the author in any work or product based on this material.
 *
 * ===========================================================================
 *
 * Author:  Anton Lavrentiev
 *
 * File Description:
 *   Special forwarding header for <connect/ncbi_localip.h> for C++ Tkit use
 *
 */


#define NcbiInitLocalIP  NcbiCXXInitLocalIP
#define NcbiIsLocalIP    NcbiCXXIsLocalIP
#define NcbiIsLocalIPEx  NcbiCXXIsLocalIPEx

#include <connect/ncbi_localip.h>


#endif  /* CONNECT___NCBI_CONN_LOCALIP__HPP */

==> ncbi-blast+_2.16.0+ds.orig.tar.xz: ncbi-blast-2.16.0+-src/c++/include/connect/ncbi_localip.hpp <==
#ifndef CONNECT___NCBI_CONN_LOCALIP__HPP
#define CONNECT___NCBI_CONN_LOCALIP__HPP

/* $Id: ncbi_localip.hpp 606403 2020-04-21 14:51:49Z lavr $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
 *               National Center for Biotechnology Information
 *
 *  This software/database is a "United States Government Work" under the
 *  terms of the United States Copyright Act.  It was written as part of
 *  the author's official duties as a United States Government employee and
 *  thus cannot be copyrighted.  This software/database is freely available
 *  to the public for use. The National Library of Medicine and the U.S.
 *  Government have not placed any restriction on its use or reproduction.
 *
 *  Although all reasonable efforts have been taken to ensure the accuracy
 *  and reliability of the software and data, the NLM and the U.S.
 *  Government do not and cannot warrant the performance or results that
 *  may be obtained by using this software or data. The NLM and the U.S.
 *  Government disclaim all warranties, express or implied, including
 *  warranties of performance, merchantability or fitness for any particular
 *  purpose.
 *
 *  Please cite the author in any work or product based on this material.
 *
 * ===========================================================================
 *
 * Author:  Anton Lavrentiev
 *
 * File Description:
 *   Special forwarding header for <connect/ncbi_localip.h> for C++ Tkit use
 *
 * @warning
 *   You MUST use this header (instead of <connect/ncbi_localip.h>) in a C++
 *   application, or risk facing undefined symbols at link time!
 *
 */


#define NcbiInitLocalIP  NcbiCXXInitLocalIP
#define NcbiIsLocalIP    NcbiCXXIsLocalIP
#define NcbiIsLocalIPEx  NcbiCXXIsLocalIPEx

#include <connect/ncbi_localip.h>


#endif  /* CONNECT___NCBI_CONN_LOCALIP__HPP */
